﻿namespace UltraTreeWrapText
{
    using System.Drawing;
    using Infragistics.Win;
    using Infragistics.Win.UltraWinTree;

    public class CF : IUIElementCreationFilter
    {
        public void AfterCreateChildElements(UIElement parent)
        {
            //  Get the node selectable area element. We need to size the text
            //  element to the size of selectable are.
            if (parent is NodeSelectableAreaUIElement)
            {
                //  Get the text element as child of selectable area
                var textElement = parent.GetDescendant(typeof(NodeTextUIElement)) as NodeTextUIElement;
                if (textElement != null)
                {
                    //  Set the text element size same as the size of selectable
                    //  area element
                    textElement.Rect = new Rectangle(textElement.Rect.Location, parent.Rect.Size);
                    textElement.WrapText = true;
                }
            }

            //  Get the tree main element in order to remove the horizontal
            //  scrollbar and resize nodes client area element
            if (parent is UltraTreeUIElement)
            {
                //  Get the horizontal scroll bar and remove it
                var horScrollElement = parent.GetDescendant(typeof(HorizontalScrollbarUIElement));
                if (horScrollElement != null)
                {
                    parent.ChildElements.Remove(horScrollElement);

                    //  Increase the node client area height accordingly
                    var nodeAreaElement = parent.GetDescendant(typeof(NodeClientAreaUIElement));
                    nodeAreaElement.Rect = new Rectangle(
                        nodeAreaElement.Rect.Location,
                        new Size(
                            nodeAreaElement.Rect.Width,
                            nodeAreaElement.Rect.Height + horScrollElement.Rect.Height));
                }
            }
        }

        public bool BeforeCreateChildElements(UIElement parent)
        {
            return false;
        }
    }
}


/*
UltraTreeUIElement, Location = {X=0,Y=0,Width=284,Height=261}
    NodeClientAreaUIElement, Location = {X=0,Y=0,Width=267,Height=244}
        TreeNodeUIElement, Location = {X=0,Y=0,Width=267,Height=100}
            NodeSelectableAreaUIElement, Location = {X=0,Y=0,Width=267,Height=100}
                NodeTextUIElement, Location = {X=0,Y=0,Width=697,Height=100} [Active]
        TreeNodeUIElement, Location = {X=0,Y=100,Width=267,Height=100}
            NodeSelectableAreaUIElement, Location = {X=0,Y=100,Width=267,Height=100}
                NodeTextUIElement, Location = {X=0,Y=100,Width=43,Height=100}
        TreeNodeUIElement, Location = {X=0,Y=200,Width=267,Height=100}
            NodeSelectableAreaUIElement, Location = {X=0,Y=200,Width=267,Height=100}
                NodeTextUIElement, Location = {X=0,Y=200,Width=44,Height=100}
    VerticalScrollbarUIElement, Location = {X=267,Y=0,Width=17,Height=244}
        ScrollArrowUIElement, Location = {X=267,Y=0,Width=17,Height=17}
        ScrollArrowUIElement, Location = {X=267,Y=227,Width=17,Height=17}
        ScrollTrackUIElement, Location = {X=267,Y=17,Width=17,Height=210}
            ScrollThumbUIElement, Location = {X=267,Y=17,Width=17,Height=42}
            ScrollTrackSubAreaUIElement, Location = {X=267,Y=59,Width=17,Height=168}
    HorizontalScrollbarUIElement, Location = {X=0,Y=244,Width=267,Height=17}
        ScrollArrowUIElement, Location = {X=0,Y=244,Width=17,Height=17}
        ScrollArrowUIElement, Location = {X=250,Y=244,Width=17,Height=17}
        ScrollTrackUIElement, Location = {X=17,Y=244,Width=233,Height=17}
            ScrollThumbUIElement, Location = {X=17,Y=244,Width=80,Height=17}
            ScrollTrackSubAreaUIElement, Location = {X=97,Y=244,Width=153,Height=17}
    ScrollbarIntersectionUIElement, Location = {X=267,Y=244,Width=17,Height=17}
*/

